@@ -6,7 +6,7 @@
 
 #define GIO_FOUND
 #define PULSEAUDIO_FOUND
-/* #undef XCB_XINPUT_FOUND */
+#define XCB_XINPUT_FOUND
 #define ENABLE_WAYLAND
 
 #define OBS_RELEASE_CANDIDATE 0
